==> webkitgtk-2.15.1.tar.xz: webkitgtk-2.15.1/Source/WebCore/svg/SVGViewSpec.h <==
/*
 * Copyright (C) 2007 Rob Buis <buis@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "SVGAnimatedPreserveAspectRatio.h"
#include "SVGAnimatedRect.h"
#include "SVGFitToViewBox.h"
#include "SVGTransformList.h"
#include "SVGZoomAndPan.h"

namespace WebCore {

class SVGElement;
class SVGTransformListPropertyTearOff;

class SVGViewSpec final : public RefCounted<SVGViewSpec>, public SVGZoomAndPan, public SVGFitToViewBox {
public:
    static Ref<SVGViewSpec> create(SVGElement& contextElement)
    {
        return adoptRef(*new SVGViewSpec(contextElement));
    }

    bool parseViewSpec(const String&);
    void reset();

    SVGElement* viewTarget() const;

    String transformString() const;
    String viewBoxString() const;
    String preserveAspectRatioString() const;
    const String& viewTargetString() const { return m_viewTargetString; }

    SVGZoomAndPanType zoomAndPan() const { return m_zoomAndPan; }
    ExceptionOr<void> setZoomAndPan(unsigned short);
    void setZoomAndPanBaseValue(unsigned short zoomAndPan) { m_zoomAndPan = SVGZoomAndPan::parseFromNumber(zoomAndPan); }

    void resetContextElement() { m_contextElement = nullptr; }

    // Custom non-animated 'transform' property.
    RefPtr<SVGTransformListPropertyTearOff> transform();
    SVGTransformList transformBaseValue() const { return m_transform; }

    // Custom animated 'viewBox' property.
    RefPtr<SVGAnimatedRect> viewBoxAnimated();
    FloatRect& viewBox() { return m_viewBox; }
    void setViewBoxBaseValue(const FloatRect& viewBox) { m_viewBox = viewBox; }

    // Custom animated 'preserveAspectRatio' property.
    RefPtr<SVGAnimatedPreserveAspectRatio> preserveAspectRatioAnimated();
    SVGPreserveAspectRatio& preserveAspectRatio() { return m_preserveAspectRatio; }
    void setPreserveAspectRatioBaseValue(const SVGPreserveAspectRatio& preserveAspectRatio) { m_preserveAspectRatio = preserveAspectRatio; }

private:
    explicit SVGViewSpec(SVGElement&);

    static const SVGPropertyInfo* transformPropertyInfo();
    static const SVGPropertyInfo* viewBoxPropertyInfo();
    static const SVGPropertyInfo* preserveAspectRatioPropertyInfo();

    static const AtomicString& transformIdentifier();
    static const AtomicString& viewBoxIdentifier();
    static const AtomicString& preserveAspectRatioIdentifier();

    static Ref<SVGAnimatedProperty> lookupOrCreateTransformWrapper(SVGViewSpec* contextElement);
    static Ref<SVGAnimatedProperty> lookupOrCreateViewBoxWrapper(SVGViewSpec* contextElement);
    static Ref<SVGAnimatedProperty> lookupOrCreatePreserveAspectRatioWrapper(SVGViewSpec* contextElement);

    SVGElement* m_contextElement;
    SVGZoomAndPanType m_zoomAndPan { SVGZoomAndPanMagnify };
    SVGTransformList m_transform;
    FloatRect m_viewBox;
    SVGPreserveAspectRatio m_preserveAspectRatio;
    String m_viewTargetString;
};

} // namespace WebCore

==> webkitgtk-2.22.0.tar.xz: webkitgtk-2.22.0/Source/WebCore/svg/SVGViewSpec.h <==
/*
 * Copyright (C) 2007 Rob Buis <buis@kde.org>
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "SVGAnimatedPreserveAspectRatio.h"
#include "SVGAnimatedRect.h"
#include "SVGFitToViewBox.h"
#include "SVGTransformListValues.h"
#include "SVGZoomAndPan.h"

namespace WebCore {

class SVGElement;
class SVGTransformList;

class SVGViewSpec final : public RefCounted<SVGViewSpec>, public SVGFitToViewBox, public SVGZoomAndPan {
public:
    static Ref<SVGViewSpec> create(SVGElement& contextElement)
    {
        return adoptRef(*new SVGViewSpec(contextElement));
    }

    bool parseViewSpec(const String&);
    void reset();
    void resetContextElement() { m_contextElement = nullptr; }

    SVGElement* viewTarget() const;
    const String& viewTargetString() const { return m_viewTargetString; }

    String transformString() const { return m_transform.toString(); }
    RefPtr<SVGTransformList> transform();
    SVGTransformListValues transformValue() const { return m_transform.value(); }

private:
    explicit SVGViewSpec(SVGElement&);

    using AttributeOwnerProxy = SVGAttributeOwnerProxyImpl<SVGViewSpec, SVGFitToViewBox, SVGZoomAndPan>;
    static void registerAttributes();

    static AttributeOwnerProxy::AttributeRegistry& attributeRegistry() { return AttributeOwnerProxy::attributeRegistry(); }
    static bool isKnownAttribute(const QualifiedName& attributeName) { return AttributeOwnerProxy::isKnownAttribute(attributeName); }

    SVGElement* m_contextElement;
    String m_viewTargetString;
    AttributeOwnerProxy m_attributeOwnerProxy;
    SVGAnimatedTransformListAttribute m_transform;
};

} // namespace WebCore
